#
# spec file for package gpsbabel
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global translationdir %{_datadir}/qt5/translations
Name:           gpsbabel
Version:        1.5.3
Release:        3.3
Summary:        Converts GPS waypoint, route and track data from one format type to another
License:        GPL-2.0+
Group:          Hardware/Other
Url:            http://www.gpsbabel.org/
Source:         %{name}-%{version}.tar.gz
Source1:        http://www.gpsbabel.org/htmldoc-1.5.0/%{name}-1.5.0.pdf
Source2:        %{name}.png
Source21:       style3.css
# Use system shapelib - not suitable for upstream in this form.
Patch2:         0002-gpsbabel-1.4.3-use-system-shapelib.patch
# Pickup gmapbase.html from /usr/share/gpsbabel
Patch3:         0003-gpsbabel-1.4.3-gmapbase.patch
# No automatic phone home by default (RHBZ 668865)
Patch4:         0004-gpsbabel-1.4.3-nosolicitation.patch
# Use system zlib
Patch6:         0006-Use-system-zlib.patch
# Use system minizip
Patch7:         0007-Use-system-minizip.patch
BuildRequires:  autoconf
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libusb-devel
BuildRequires:  minizip-devel
BuildRequires:  pkgconfig
BuildRequires:  shapelib-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GPSBabel converts waypoints, tracks, and routes from one format to
another, whether that format is a common mapping format like Delorme,
Streets and Trips, or even a serial upload or download to a GPS unit
such as those from Garmin and Magellan. By flattening the Tower of
Babel that the authors of various programs for manipulating GPS data
have imposed upon us, it returns to us the ability to freely move our
own waypoint data between the programs and hardware we choose to use.

It contains extensive data manipulation abilities making it a
convenient for server-side processing or as the backend for other
tools.

It does not convert, transfer, send, or manipulate maps. We process
data that may (or may not be) placed on a map, such as waypoints,
tracks, and routes.

%package gui
Summary:        Qt GUI interface for GPSBabel
Group:          Hardware/Other
Requires:       %{name} = %{version}-%{release}
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description gui
Qt GUI interface for GPSBabel

%prep
%setup -q
# Use system shapelib instead of bundled partial shapelib
rm -rf shapelib
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch6 -p1
%patch7 -p1

# Get rid of bundled zlib
# configure --with-zlib=system is not enough,
# building still accesses bundled zlib headers
rm -rf zlib/*
touch zlib/empty.in

cp -p %{SOURCE21} gpsbabel.org-style3.css

# Avoid calling autoconf from Makefile
touch -r configure.in configure Makefile.in

# Fixup categories for .desktop file
sed -i \
    -e 's:Utility;::g' \
    gui/gpsbabel.desktop

%build
export CXXFLAGS="%{optflags} -fPIC"
%configure\
	--with-zlib=system
make %{?_smp_mflags}
cp %{SOURCE1} %{name}.pdf

pushd gui
CFLAGS="%{optflags}" \
%qmake5 PREFIX=%{_prefix}
lrelease-qt5 *.ts
make %{?_smp_mflags}
popd

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

make -C gui DESTDIR=%{buildroot} install

install -m 0755 -p gui/objects/gpsbabelfe-bin %{buildroot}/%{_bindir}
install -m 0755 -d %{buildroot}/%{translationdir}
install -m 0644 -p gui/gpsbabel*_*.qm %{buildroot}/%{translationdir}/

install -m 0755 -d %{buildroot}/%{_datadir}/applications
install -m 0644 gui/gpsbabel.desktop %{buildroot}/%{_datadir}/applications

install -m 0755 -d            %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/
install -m 0644 -p %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/

%find_lang %{name} --with-qt --all-name

%post gui
%icon_theme_cache_post
%desktop_database_post

%postun gui
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README* %{name}.pdf
%{_bindir}/gpsbabel
%{_bindir}/gpsbabelfe-bin
%{_datadir}/applications/*
%dir %{translationdir}/
%{translationdir}/*
%dir %{_datadir}/icons/hicolor/256x256/
%dir %{_datadir}/icons/hicolor/256x256/apps/
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png

%changelog
* Thu Jun 30 2016 rmaliska@suse.com
- Updated to 1.5.3
  * no changelog available
- refreshed 2 patches:
  * 0002-gpsbabel-1.4-em-shapelib.patch
  * 0006-Use-system-zlib.patch
- added patch:
  * 0007-Use-system-minizip.patch
* Sun Jun  5 2016 mpluskal@suse.com
- Update dependencies
* Sun May 31 2015 tchvatal@suse.com
- Use qmake macro and obey cflags
* Fri May 29 2015 mpluskal@suse.com
- Add post/postun dependencies for update-desktop-files
* Fri May 29 2015 dgutu@suse.com
- Defined icon and translation directories in %%files section
  on spec file
* Thu May 28 2015 dgutu@suse.com
- Spec file modified to reflect changes about icon and desktop file
- Added the gpsbabel.png
* Thu May 28 2015 dgutu@suse.com
- Added missing packages for gui version to spec file
  * libqt5-qtwebkit
  * shapelib-devel
  * update-desktop-files
  * autoconf
- Added patches
  * 0002-gpsbabel-1.4.3-use-system-shapelib.patch
  * 0003-gpsbabel-1.4.3-gmapbase.patch
  * 0004-gpsbabel-1.4.3-nosolicitation.patch
  * 0006-Use-system-zlib.patch
* Wed May 27 2015 dimstar@opensuse.org
- Build Position Independent Code (as required by Qt5): inject
  - fPIC into CXXFLAGS.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 1.5.2
  * Add read support for Google's "gx:track" extension to KML.
  * Ralf Horstmann adds Mynav Map Manager and VDO GP7.
  * White B. Coot adds F90G support.
  * Zingo Andersonadds Energympro sport watches.
  * Support altitude in mainnav.
  * Many fixes for malformed input.
  * Improve reading KML without altitudes.
  * Improved sub-second handling in unicsv.
  * Better handling of GPX 1.1 metadata.
  * GUI allows waypoint reads for MTK logger. MTK reads no longer write
    a temp file in the application directory.
- Changes from version 1.5.1
  * Add options to discard filter to discard points based on regular
    expressions.
  * Experimental support for for faster Garmin serial download speeds.
  * Windows binary formats that used seek (notably Garmin POI) could
    return EOF prematurely because of a bad interaction with a new
    zlib library.
  * Users upgrading from an older version will no longer presented with
    a character set option in the GUI that doesn't work.
  * TODO: list more.
- Changes from version 1.5.0
  * Too much to list here
    http://www.gpsbabel.org/news/gpsbabel-1.5.0.html
- Add new upstream dependencies: libqt5-qtbase-devel and libqt5-qttools-devel
- Remove depreciated AUTHORS section
- Remove redundant %%clean section
- Upstream doesn't provide 'contrib' anymore; do not perform %%doc
  on it
- Update pdf file to 1.5.0
- Use download Url as source for pdf file
* Fri Mar 29 2013 adrian@suse.de
- Update to version 1.4.4
  * Add MotoActiv format
  * Kris Beevers contributes Lowrance USR v4 support.
  * Allow EXIF to represent altitude below MSL.
  * Allow reading known invalid (sigh) data in NMEA, such as that written by Canon Camera/GPS devices, probably including:
  - Canon GPS shoes:
    GP-E1
    GP-E2
  - Powershot models with GPS capabilities
    S100
    SX260
    HS D20
  * Enhance Garmin Fit support for latest firmware.
  * Skytraq fixes.
  * Steve Eckert adds line styling to the National Geographic TPO3 reader.
  * Erik Krause improves German translations.
* Wed Feb  1 2012 kukuk@suse.de
- Update to version 1.4.3
  - last bug fix release before rewrite
* Tue Dec 14 2010 kukuk@suse.de
- Update to version 1.4.2
  - lot of new formats/devices and features.
* Thu Apr 16 2009 sbrabec@suse.cz
- Set USB EP IN flag for USB reads (bnc#443861).
* Mon Dec 29 2008 utx@penguin.cz
- Updated to version 1.3.6:
  * Support for Holux M241, Iblue747, Igo8, VidaOne version 2,
    Navigon Wpt format, Medion GoPal, Humminbird format, Lowrance
    .usr version 3 support, Mapasia tr7, Google Navigator, Navitel,
    Geogrid Viewer, iGO2008 POI support, Jelbert GeoTagger format,
    Skyforce, SBP format for LocoSys GPS, Memory-Map Navigator
    Overlay support.
  * Garmin mass storage device detection.
  * Discard feature can now toss points with no or unknown fix.
  * NMEA reader now can read AMOD 3080GL waypoints.
  * Garmin Training Center now does lap splitting, can now read.
  * Added the height filter.
  * AN1->KML conversions now preserve line colors.
  * Doc improvements.
  * Route reversal can reverse tracks, too.
  * Magellan geocache files can now be read.
  * Workaround for Garmin Venture HC weirdness on Mac and Linux.
  * Entity encoding problem in Google Earth KML writer for
    Geocaches.
  * Fix NMEA writer bug that caused everthing to be a GISTeq file.
  * Fix writing waypoint names under 6 characters to old serial
    Garmins.
  * Several improvements to Navilink.
* Sat Sep 20 2008 sndirsch@suse.de
- picked up gpsbabel package from external buildservice
  (project Application:Geo); reviewed changes of
  gpsbabel-1.3.4-docbook.patch and new patch
  gpsbabel-1.3.5-link-clash.patch; verified that new source tarball
  has not been modified and pdf documentation has been updated to
  release 1.3.5
* Wed Aug 13 2008 utx@penguin.cz
- Updated to version 1.3.5:
  * new formats: GlobalSat DG-100, Navilink GPS support, MTK Data
    Logger, Nokia LMX, Swiss Map 50 xol, NMEA GISTeq strain.
  * new features: Garmin HC supported, Garmin GPI proximity alerts,
    Lowrance waypoint comments, VCF coords in ADR for iPhone,
    timestamps in KML Placemarks, Opencaching.de GPX, TomTom
    geocaching, KML writer for geocaches rewritten, KML track/route
    writer direction of motion, GPX and CSV Geocache
    archive/availability, discard filter support for minimum number
    of satellites.
  * fixes: Google Maps reader, longitude and latitude in tomtom_in,
    Garmin GDB Category option, timestamps on xcsv formats,
    realtime KML GPS jitter suppress, GPX links handled in tracks
    and routes.
* Fri Jun 27 2008 schwab@suse.de
- Fix configure script.
* Sun May  4 2008 aj@suse.de
- Add patch to support Wintec WSG1000.
* Mon Aug 20 2007 nadvornik@suse.cz
- installed documentation in pdf format [#301831]
* Tue Aug  7 2007 nadvornik@suse.cz
- updated to 1.3.4:
  * new or improved formats:
    Earthcaches and Events now included in Garmin -Sn handlers.
    GDB Version 3 (as in latest Mapsource beta) now supported.
    New Garmin icons added. More closely tracks official names.
    Adds support for reading Streets & Trips 2007 .est files.
    GPX now handles millisecond time resolution.
    Google Earth KML writer now uses Earth 2.1 XSD; all output validates.
    Kompass DAV files now supported.
    DATUM now available in XCSV formats.
    CoPilot updated.
    Raymarine added.
    PCX reader now handles more files from GPSUtil.
    Tabsep format how processes 'hint' and 'last found' on geocaches.
    Vitovtt tracks
    NMEA and XSV realtime tracking output.
    EADS Geogrid Viewer.
    G7towin .g7t.
    TomTom POI ascii files.
    Garmin POI gpi files.
    Multiple URL support in GDB and GPX.
    Microsecond resolution in many formats.
    Enhancements to KML output for Google Earth.
    Support for WBT 201.
    Enhance NMEA reader to handle Sony GPS and GISTeq
    Many enhancements to Unicsv format.
  * GPS support:
    AVMAP EKP-IV support added in NMEA module.
    Sony GPS1 now supported in NMEA module.
    Alan Map 500 and Holux GM101 are now supported.
    Zumo 450, Nuvi 670, Nuvi 680, Nuvi 370, StreetPilot C580, and Astro supported.
    Sirf GPSes (such as Microsoft's rebranded unti) now supported by NMEA realtime tracking mode.
  * replaced coldsync code
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Sat Apr 28 2007 aj@suse.de
- Add libexpat-devel to BuildRequires.
* Thu Mar 29 2007 ro@suse.de
- added zlib-devel to buildreq
* Mon Nov 13 2006 nadvornik@suse.cz
- removed code from coldsync subdirectory, due to possible license
  incompatibility; build with --enable-pdb=no [#217379]
- added fix for tracklog interpolation
* Fri Oct 20 2006 nadvornik@suse.cz
- new package, version 1.3.1
